dew_kanban library

Classes

ColumnConfig
KanbanCommand
Top-level CLI command for all Kanban board operations.
KanbanConfig
KanbanInitHook
Ticket
A typed, directed link from one ticket to another.
TicketStore
TicketTypeConfig

Extensions

KanbanDewConfig on DewConfig
KanbanDirs on ProjectDirs
Extends ProjectDirs with the kanban board directory.

Constants

linkTypeInverses → const Map<String, String>
The valid relationship types between tickets, and their inverses.

Functions

registerCommands(CommandRegistry registry, {FileSystem fs = const LocalFileSystem()}) → void
Registers all Kanban commands and init hooks into registry.